import {select, arc} from 'd3';

const svg = select('svg');

// .attr() without arg accesses the specified value
const width = parseFloat(svg.attr('width'));
const height = +svg.attr('height');

// we can call .append() on d3.selection to append DOM elements (create child tag)
// the appended DOM element gets returned
const circle = svg.append('circle');
// .attr() returns the selection it was called on
circle.attr('r', height/2)
	.attr('cx', width/2)
	.attr('cy', height/2)
	.attr('fill', 'yellow')
  .attr('stroke', 'black')
  .attr('stroke-width', 20);

const eyeSpacing = 100;
const eyeYOffset = -70;
const eyeRadius = 50;
const eyebrowWidth = 90;
const eyebrowHeight = 30;
const eyebrowYOffset = -90;

const mouthEyeGroup = svg
	.append('g')
		.attr('transform', `translate(${width/2}, ${height/2})`);

const eyesG = mouthEyeGroup
	.append('g')
    .attr('transform', `translate(0, ${eyeYOffset})`)
    .attr('fill', '#0eb7c7');

const leftEye = eyesG
	.append('circle')
    .attr('r', eyeRadius)
    .attr('cx', -eyeSpacing);

const rightEye = eyesG
	.append('circle')
    .attr('r', eyeRadius)
    .attr('cx', eyeSpacing);

//// Animation with .transition().duration() ////
const eyebrowsG = eyesG
	.append('g')																						 // .append() returns DOM
		.attr('transform', `translate(0, ${eyebrowYOffset})`)  // but .transition() doesn't

// you can't add DOM elements to .transition() so we need to add .transition separately like below
eyebrowsG
  .transition().duration(2000)
		.attr('transform', `translate(0, ${eyebrowYOffset - 50})`)  // you can chain .transitions()
	.transition().duration(2000)
  	.attr('transform', `translate(0, ${eyebrowYOffset})`);

const leftEyebrow = eyebrowsG
	.append('rect')
    .attr('x', -eyeSpacing - eyebrowWidth/2)
    .attr('width', eyebrowWidth)
    .attr('height', eyebrowHeight);

const rightEyebrow = eyebrowsG
	.append('rect')
    .attr('x', eyeSpacing - eyebrowWidth/2)
    .attr('width', eyebrowWidth)
    .attr('height', eyebrowHeight);

const mouth = mouthEyeGroup
	.append('path')
    .attr('d', arc()({
      innerRadius: 130,
      outerRadius: 150,
      startAngle: Math.PI / 2,
      endAngle: Math.PI * 3/2
    }));
